# Generated by roxygen2: do not edit by hand

S3method(print,gedi_dynamics)
S3method(print,gedi_dynamics_svd)
S3method(print,gedi_imputation)
S3method(print,gedi_pathway_associations)
export(CreateGEDIObject)
export(check_optional_dependencies)
export(gedi_to_seurat)
export(install_optional_dependencies)
export(list_h5_structure)
export(plot_convergence)
export(plot_dispersion)
export(plot_embedding)
export(plot_feature_ratio)
export(plot_features)
export(plot_vector_field)
export(read_h5)
export(read_h5ad)
export(seurat_to_gedi)
export(write_h5ad)
import(Matrix)
import(R6)
importFrom(Matrix,Matrix)
importFrom(Matrix,sparseMatrix)
importFrom(Matrix,t)
importFrom(Rcpp,sourceCpp)
importFrom(methods,as)
importFrom(methods,is)
importFrom(stats,coef)
importFrom(stats,median)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,var)
importFrom(utils,object.size)
importFrom(utils,packageVersion)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(gedi2, .registration = TRUE)
