% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gedi_plot_utils.R
\name{theme_gedi}
\alias{theme_gedi}
\title{GEDI Plot Theme}
\usage{
theme_gedi(base_size = 11)
}
\value{
A \code{ggplot2} theme object.
}
\description{
GEDI Plot Theme
}
\keyword{internal}
